Operating System

Linux Windows macOS/OSX

Package manager

pip conda source

Configuration

Jupyter Lab Virtual environment

    pip install -U pycalphad

    pip install -U pycalphad jupyterlab

    python -m venv pycalphad-env
    source pycalphad-env/bin/activate
    pip install -U pycalphad

    python -m venv pycalphad-env
    source pycalphad-env/bin/activate
    pip install -U pycalphad jupyterlab

    pip install -U pycalphad

    pip install -U pycalphad jupyterlab

    python -m venv pycalphad-env
    pycalphad-env\Scripts\activate
    pip install -U pycalphad

    python -m venv pycalphad-env
    pycalphad-env\Scripts\activate
    pip install -U pycalphad jupyterlab

    conda install -c conda-forge pycalphad

    conda install -c conda-forge pycalphad jupyterlab

    conda create -n pycalphad-env python
    conda activate pycalphad-env
    conda install -c conda-forge pycalphad

    conda create -n pycalphad-env python
    conda activate pycalphad-env
    conda install -c conda-forge pycalphad jupyterlab

    conda install -c conda-forge pycalphad

    conda install -c conda-forge pycalphad jupyterlab

    conda create -n pycalphad-env python
    conda activate pycalphad-env
    conda install -c conda-forge pycalphad

    conda create -n pycalphad-env python
    conda activate pycalphad-env
    conda install -c conda-forge pycalphad jupyterlab

    git clone https://github.com/pycalphad/pycalphad
    cd pycalphad
    pip install -U pip setuptools
    pip install -U -r requirements-dev.txt
    pip install -U --no-build-isolation --editable .

    git clone https://github.com/pycalphad/pycalphad
    cd pycalphad
    pip install -U pip setuptools
    pip install -U -r requirements-dev.txt
    pip install -U --no-build-isolation --editable .
    pip install -U jupyterlab

    python -m venv pycalphad-env
    source pycalphad-env/bin/activate
    git clone https://github.com/pycalphad/pycalphad
    cd pycalphad
    pip install -U pip setuptools
    pip install -U -r requirements-dev.txt
    pip install -U --no-build-isolation --editable .

    python -m venv pycalphad-env
    source pycalphad-env/bin/activate
    git clone https://github.com/pycalphad/pycalphad
    cd pycalphad
    pip install -U pip setuptools
    pip install -U -r requirements-dev.txt
    pip install -U --no-build-isolation --editable .
    pip install -U jupyterlab

    git clone https://github.com/pycalphad/pycalphad
    cd pycalphad
    pip install -U pip setuptools
    pip install -U -r requirements-dev.txt
    pip install -U --no-build-isolation --editable .

    git clone https://github.com/pycalphad/pycalphad
    cd pycalphad
    pip install -U pip setuptools
    pip install -U -r requirements-dev.txt
    pip install -U --no-build-isolation --editable .
    pip install -U jupyterlab

    python -m venv pycalphad-env
    pycalphad-env\Scripts\activate
    git clone https://github.com/pycalphad/pycalphad
    cd pycalphad
    pip install -U pip setuptools
    pip install -U -r requirements-dev.txt
    pip install -U --no-build-isolation --editable .

    python -m venv pycalphad-env
    pycalphad-env\Scripts\activate
    git clone https://github.com/pycalphad/pycalphad
    cd pycalphad
    pip install -U pip setuptools
    pip install -U -r requirements-dev.txt
    pip install -U --no-build-isolation --editable .
    pip install -U jupyterlab